==> jc-1.4.0.tar.gz: java/awt/image/BufferedImage__241.h <==
// final class java.awt.image.BufferedImage$1

// class file dependencies
// @dep_class 44b9f4d24e376dd6 java_awt_image_BufferedImage__241
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_BufferedImage__241_H_
#define _JC_java_awt_image_BufferedImage__241_H_

// Forward structure declarations
struct _jc_java_awt_image_BufferedImage$object;
struct _jc_java_awt_image_ImageConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;

// Typedefs
typedef struct _jc_java_awt_image_BufferedImage__241$sub_refs	_jc_java_awt_image_BufferedImage__241$sub_refs;
typedef struct _jc_java_awt_image_BufferedImage__241$sub_nonrefs	_jc_java_awt_image_BufferedImage__241$sub_nonrefs;
typedef struct _jc_java_awt_image_BufferedImage__241$refs	_jc_java_awt_image_BufferedImage__241$refs;
typedef struct _jc_java_awt_image_BufferedImage__241$nonrefs	_jc_java_awt_image_BufferedImage__241$nonrefs;
typedef struct _jc_java_awt_image_BufferedImage__241$object	_jc_java_awt_image_BufferedImage__241$object;

typedef const struct _jc_java_awt_image_BufferedImage__241$vmethods	_jc_java_awt_image_BufferedImage__241$vmethods;
typedef const struct _jc_java_awt_image_BufferedImage__241$vtable	_jc_java_awt_image_BufferedImage__241$vtable;
typedef const struct _jc_java_awt_image_BufferedImage__241$vtype	_jc_java_awt_image_BufferedImage__241$vtype;

// Constructors
extern void _jc_java_awt_image_BufferedImage__241$method$_init$b5d3cd9033e59aed(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_java_awt_image_BufferedImage$object *);

// Virtual methods
extern void _jc_java_awt_image_BufferedImage__241$method$addConsumer$280f4229ae568632(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
extern jboolean _jc_java_awt_image_BufferedImage__241$method$isConsumer$2e7ee3184ebf4388(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
extern void _jc_java_awt_image_BufferedImage__241$method$removeConsumer$c1effed99882a87d(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
extern void _jc_java_awt_image_BufferedImage__241$method$requestTopDownLeftRightResend$9c3b642896e809d4(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
extern void _jc_java_awt_image_BufferedImage__241$method$startProduction$34c5bb40595e132a(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
extern void _jc_java_awt_image_BufferedImage__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$addConsumer$280f4229ae568632;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$isConsumer$2e7ee3184ebf4388;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$removeConsumer$c1effed99882a87d;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$requestTopDownLeftRightResend$9c3b642896e809d4;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$startProduction$34c5bb40595e132a;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_image_BufferedImage__241$vmethods {
	void	(*addConsumer$280f4229ae568632)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
	jboolean	(*isConsumer$2e7ee3184ebf4388)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
	void	(*removeConsumer$c1effed99882a87d)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
	void	(*requestTopDownLeftRightResend$9c3b642896e809d4)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
	void	(*startProduction$34c5bb40595e132a)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *);
};

// Vtable
struct _jc_java_awt_image_BufferedImage__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_BufferedImage__241$vmethods	java_awt_image_BufferedImage__241;
};

// Vtype
struct _jc_java_awt_image_BufferedImage__241$vtype {
	_jc_type			type;
	_jc_java_awt_image_BufferedImage__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImage__241$sub_refs {
	struct _jc_java_util_HashSet$object	*consumers;
	struct _jc_java_awt_image_BufferedImage$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_image_BufferedImage__241$refs {
    _jc_java_awt_image_BufferedImage__241$sub_refs	java_awt_image_BufferedImage__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImage__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_BufferedImage__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_BufferedImage__241$sub_nonrefs	java_awt_image_BufferedImage__241;
};

// Object instance structure
struct _jc_java_awt_image_BufferedImage__241$object {
	_jc_java_awt_image_BufferedImage__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_BufferedImage__241$vtype	*vtype;
	_jc_java_awt_image_BufferedImage__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_BufferedImage__241$vtype _jc_java_awt_image_BufferedImage__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_BufferedImage__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_BufferedImage__241$class_object;

#endif	/* _JC_java_awt_image_BufferedImage__241_H_ */

==> jc-1.4.5.tar.gz: java/awt/image/BufferedImage__241.h <==
// final class java.awt.image.BufferedImage$1

// class file dependencies
// @dep_class 44b9f4d24e376dd6 java_awt_image_BufferedImage__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_BufferedImage__241_H_
#define _JC_java_awt_image_BufferedImage__241_H_

// Forward structure declarations
struct _jc_java_awt_image_BufferedImage$object;
struct _jc_java_awt_image_ImageConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;

// Typedefs
typedef struct _jc_java_awt_image_BufferedImage__241$sub_refs	_jc_java_awt_image_BufferedImage__241$sub_refs;
typedef struct _jc_java_awt_image_BufferedImage__241$sub_nonrefs	_jc_java_awt_image_BufferedImage__241$sub_nonrefs;
typedef struct _jc_java_awt_image_BufferedImage__241$refs	_jc_java_awt_image_BufferedImage__241$refs;
typedef struct _jc_java_awt_image_BufferedImage__241$nonrefs	_jc_java_awt_image_BufferedImage__241$nonrefs;
typedef struct _jc_java_awt_image_BufferedImage__241$object	_jc_java_awt_image_BufferedImage__241$object;

typedef const struct _jc_java_awt_image_BufferedImage__241$vmethods	_jc_java_awt_image_BufferedImage__241$vmethods;
typedef const struct _jc_java_awt_image_BufferedImage__241$vtable	_jc_java_awt_image_BufferedImage__241$vtable;
typedef const struct _jc_java_awt_image_BufferedImage__241$vtype	_jc_java_awt_image_BufferedImage__241$vtype;

// Constructors
extern void _jc_java_awt_image_BufferedImage__241$method$_init$b5d3cd9033e59aed(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_java_awt_image_BufferedImage$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_image_BufferedImage__241$method$addConsumer$280f4229ae568632(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_image_BufferedImage__241$method$isConsumer$2e7ee3184ebf4388(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferedImage__241$method$removeConsumer$c1effed99882a87d(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferedImage__241$method$requestTopDownLeftRightResend$9c3b642896e809d4(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferedImage__241$method$startProduction$34c5bb40595e132a(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_BufferedImage__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$addConsumer$280f4229ae568632;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$isConsumer$2e7ee3184ebf4388;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$removeConsumer$c1effed99882a87d;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$requestTopDownLeftRightResend$9c3b642896e809d4;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$startProduction$34c5bb40595e132a;
extern _jc_method _jc_java_awt_image_BufferedImage__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_image_BufferedImage__241$vmethods {
	void	(*addConsumer$280f4229ae568632)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isConsumer$2e7ee3184ebf4388)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*removeConsumer$c1effed99882a87d)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*requestTopDownLeftRightResend$9c3b642896e809d4)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*startProduction$34c5bb40595e132a)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_image_BufferedImage__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_BufferedImage__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_BufferedImage__241$vmethods	java_awt_image_BufferedImage__241;
};

// Vtype
struct _jc_java_awt_image_BufferedImage__241$vtype {
	_jc_type			type;
	_jc_java_awt_image_BufferedImage__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImage__241$sub_refs {
	struct _jc_java_util_HashSet$object	*consumers;
	struct _jc_java_awt_image_BufferedImage$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_image_BufferedImage__241$refs {
    _jc_java_awt_image_BufferedImage__241$sub_refs	java_awt_image_BufferedImage__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_BufferedImage__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_BufferedImage__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_BufferedImage__241$sub_nonrefs	java_awt_image_BufferedImage__241;
};

// Object instance structure
struct _jc_java_awt_image_BufferedImage__241$object {
	_jc_java_awt_image_BufferedImage__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_BufferedImage__241$vtype	*vtype;
	_jc_java_awt_image_BufferedImage__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_BufferedImage__241$vtype _jc_java_awt_image_BufferedImage__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_BufferedImage__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_BufferedImage__241$class_object;

#endif	/* _JC_java_awt_image_BufferedImage__241_H_ */
